summaryrefslogtreecommitdiff
path: root/mpn/i960
diff options
context:
space:
mode:
authorKevin Ryde <user42@zip.com.au>2000-04-16 00:46:46 +0200
committerKevin Ryde <user42@zip.com.au>2000-04-16 00:46:46 +0200
commitb411202ebcc8f817116fe7422683b52293b522f6 (patch)
tree98ad8121f767fce9c2b64dfa315ed22100719103 /mpn/i960
parent733ba8f43f4f96953fe416250cf8390571b69947 (diff)
downloadgmp-b411202ebcc8f817116fe7422683b52293b522f6.tar.gz
Change __mpn to __gmpn.
Diffstat (limited to 'mpn/i960')
-rw-r--r--mpn/i960/add_n.s6
-rw-r--r--mpn/i960/addmul_1.s6
-rw-r--r--mpn/i960/mul_1.s6
-rw-r--r--mpn/i960/sub_n.s6
4 files changed, 12 insertions, 12 deletions
diff --git a/mpn/i960/add_n.s b/mpn/i960/add_n.s
index 6e674822c..2f23fc504 100644
--- a/mpn/i960/add_n.s
+++ b/mpn/i960/add_n.s
@@ -1,4 +1,4 @@
# I960 __mpn_add_n -- Add two limb vectors of the same length > 0 and store
# sum in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -22,8 +22,8 @@
.text
.align 4
- .globl ___mpn_add_n
-___mpn_add_n:
+ .globl ___gmpn_add_n
+___gmpn_add_n:
mov 0,g6 # clear carry-save register
cmpo 1,0 # clear cy
@@ -1,4 +1,4 @@
-# I960 __mpn_add_n -- Add two limb vectors of the same length > 0 and store
+# I960 __gmpn_add_n -- Add two limb vectors of the same length > 0 and store
# sum in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
diff --git a/mpn/i960/addmul_1.s b/mpn/i960/addmul_1.s
index db53f64e2..b3962c1ca 100644
--- a/mpn/i960/addmul_1.s
+++ b/mpn/i960/addmul_1.s
@@ -1,4 +1,4 @@
# I960 __mpn_addmul_1 -- Multiply a limb vector with a limb and add
# the result to a second limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -22,8 +22,8 @@
.text
.align 4
- .globl ___mpn_mul_1
-___mpn_mul_1:
+ .globl ___gmpn_mul_1
+___gmpn_mul_1:
subo g2,0,g2
shlo 2,g2,g4
subo g4,g1,g1
@@ -1,4 +1,4 @@
-# I960 __mpn_addmul_1 -- Multiply a limb vector with a limb and add
+# I960 __gmpn_addmul_1 -- Multiply a limb vector with a limb and add
# the result to a second limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
diff --git a/mpn/i960/mul_1.s b/mpn/i960/mul_1.s
index 4ccaeabc4..543278c0b 100644
--- a/mpn/i960/mul_1.s
+++ b/mpn/i960/mul_1.s
@@ -1,4 +1,4 @@
# I960 __mpn_mul_1 -- Multiply a limb vector with a limb and store
# the result in a second limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -22,8 +22,8 @@
.text
.align 4
- .globl ___mpn_mul_1
-___mpn_mul_1:
+ .globl ___gmpn_mul_1
+___gmpn_mul_1:
subo g2,0,g2
shlo 2,g2,g4
subo g4,g1,g1
@@ -1,4 +1,4 @@
-# I960 __mpn_mul_1 -- Multiply a limb vector with a limb and store
+# I960 __gmpn_mul_1 -- Multiply a limb vector with a limb and store
# the result in a second limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
diff --git a/mpn/i960/sub_n.s b/mpn/i960/sub_n.s
index 01b94a172..278a4aa3d 100644
--- a/mpn/i960/sub_n.s
+++ b/mpn/i960/sub_n.s
@@ -1,4 +1,4 @@
# I960 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.
@@ -22,8 +22,8 @@
.text
.align 4
- .globl ___mpn_sub_n
-___mpn_sub_n:
+ .globl ___gmpn_sub_n
+___gmpn_sub_n:
mov 1,g6 # set carry-save register
cmpo 1,0 # clear cy
@@ -1,4 +1,4 @@
-# I960 __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and
+# I960 __gmpn_sub_n -- Subtract two limb vectors of the same length > 0 and
# store difference in a third limb vector.
# Copyright (C) 1995 Free Software Foundation, Inc.